@@ -2,7 +2,7 @@
  *
  * zlib compression algorithm
  * 
- * $Id: zlib.c,v 1.30 2001/02/25 22:38:22 nisse Exp $ */
+ * $Id: zlib.c,v 1.30.2.1 2001/09/26 16:13:32 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -78,7 +78,7 @@ static const struct zlib_type
 zlib_inflate = {  inflateEnd, "inflate" };
 
 static const struct zlib_type
-zlib_deflate = {  inflateEnd, "deflate" };
+zlib_deflate = {  deflateEnd, "deflate" };
 
 /* zlib memory functions */
 static void *
